==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiWidgets/QToolBarChangeEvent_shell.cpp <==
#include "QToolBarChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QToolBarChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QToolBarChangeEvent")
    QToolBarChangeEvent *_ptr = reinterpret_cast<QToolBarChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QToolBarChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QToolBarChangeEvent_shell) ); }

jmethodID QToolBarChangeEvent_shell::__shell_javaMethod(int pos) const { return QToolBarChangeEvent_shell::__shell()->javaMethod(typeid(QToolBarChangeEvent), pos); }

// emitting (writeShellConstructor)
QToolBarChangeEvent_shell::QToolBarChangeEvent_shell(bool t0)
    : QToolBarChangeEvent(t0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QToolBarChangeEvent::QToolBarChangeEvent_shell(bool t0)", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->constructed(typeid(QToolBarChangeEvent));
}

// emitting (writeShellDestructor)
QToolBarChangeEvent_shell::~QToolBarChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QToolBarChangeEvent::~QToolBarChangeEvent()", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->destructed(typeid(QToolBarChangeEvent));
}

void QToolBarChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QToolBarChangeEvent_shell*>(ptr)->QToolBarChangeEvent_shell::__shell()->tryDeleteShell(typeid(QToolBarChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QToolBarChangeEvent(bool)
void __qt_construct_QToolBarChangeEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QToolBarChangeEvent(bool)")
    jboolean t0 = __java_arguments[0].z;
    Q_UNUSED(t0)
    QToolBarChangeEvent *__qt_this = new(__qtjambi_ptr) QToolBarChangeEvent_shell(static_cast<bool>(t0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QToolBarChangeEvent_shell
void __qt_destruct_QToolBarChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QToolBarChangeEvent")
    reinterpret_cast<QToolBarChangeEvent_shell*>(ptr)->~QToolBarChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QToolBarChangeEvent::QToolBarChangeEvent(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_initialize_1native__Lio_qt_widgets_QToolBarChangeEvent_2Z)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jboolean t0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolBarChangeEvent::QToolBarChangeEvent(bool)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.z = t0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QToolBarChangeEvent_0, sizeof(QToolBarChangeEvent_shell), typeid(QToolBarChangeEvent), true, &deleter_QToolBarChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QToolBarChangeEvent::toggle()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_toggle_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QToolBarChangeEvent::toggle()const", __qt_this)
        __java_return_value = __qt_this->toggle();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QToolBarChangeEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QToolBarChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QToolBarChangeEvent>("QToolBarChangeEvent", "io/qt/widgets/QToolBarChangeEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QToolBarChangeEvent, {
        ConstructorInfo(&__qt_construct_QToolBarChangeEvent_0, "Z")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QToolBarChangeEvent);
    registerSizeOfShell(typeId, sizeof(QToolBarChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QToolBarChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QToolBarChangeEvent_shell.cpp <==
#include "QToolBarChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QToolBarChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QToolBarChangeEvent")
    QToolBarChangeEvent *_ptr = reinterpret_cast<QToolBarChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QToolBarChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QToolBarChangeEvent_shell) ); }

jmethodID QToolBarChangeEvent_shell::__shell_javaMethod(int pos) const { return QToolBarChangeEvent_shell::__shell()->javaMethod(typeid(QToolBarChangeEvent), pos); }

// emitting (writeShellConstructor)
QToolBarChangeEvent_shell::QToolBarChangeEvent_shell(const QToolBarChangeEvent& other0)
    : QToolBarChangeEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QToolBarChangeEvent::QToolBarChangeEvent_shell(const QToolBarChangeEvent& other0)", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->constructed(typeid(QToolBarChangeEvent));
}

QToolBarChangeEvent_shell::QToolBarChangeEvent_shell(bool t0)
    : QToolBarChangeEvent(t0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QToolBarChangeEvent::QToolBarChangeEvent_shell(bool t0)", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->constructed(typeid(QToolBarChangeEvent));
}

// emitting (writeShellDestructor)
QToolBarChangeEvent_shell::~QToolBarChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QToolBarChangeEvent::~QToolBarChangeEvent()", QToolBarChangeEvent_shell::__shell())
    QToolBarChangeEvent_shell::__shell()->destructed(typeid(QToolBarChangeEvent));
}

void QToolBarChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QToolBarChangeEvent_shell*>(ptr)->QToolBarChangeEvent_shell::__shell()->tryDeleteShell(typeid(QToolBarChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QToolBarChangeEvent(QToolBarChangeEvent)
void __qt_construct_QToolBarChangeEvent_cref_QToolBarChangeEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QToolBarChangeEvent(QToolBarChangeEvent)")
    jobject other0 = __java_arguments[0].l;
    const QToolBarChangeEvent& __qt_other0 = qtjambi_cast<const QToolBarChangeEvent& >(__jni_env, other0);
    QToolBarChangeEvent *__qt_this = new(__qtjambi_ptr) QToolBarChangeEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QToolBarChangeEvent::QToolBarChangeEvent(QToolBarChangeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_initialize_1native__Lio_qt_widgets_QToolBarChangeEvent_2Lio_qt_widgets_QToolBarChangeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolBarChangeEvent::QToolBarChangeEvent(QToolBarChangeEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QToolBarChangeEvent_cref_QToolBarChangeEvent, sizeof(QToolBarChangeEvent_shell), typeid(QToolBarChangeEvent), true, &deleter_QToolBarChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QToolBarChangeEvent(bool)
void __qt_construct_QToolBarChangeEvent_bool(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QToolBarChangeEvent(bool)")
    jboolean t0 = __java_arguments[0].z;
    Q_UNUSED(t0)
    QToolBarChangeEvent *__qt_this = new(__qtjambi_ptr) QToolBarChangeEvent_shell(static_cast<bool>(t0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QToolBarChangeEvent::QToolBarChangeEvent(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_initialize_1native__Lio_qt_widgets_QToolBarChangeEvent_2Z)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jboolean t0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QToolBarChangeEvent::QToolBarChangeEvent(bool)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.z = t0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QToolBarChangeEvent_bool, sizeof(QToolBarChangeEvent_shell), typeid(QToolBarChangeEvent), true, &deleter_QToolBarChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QToolBarChangeEvent_shell
void __qt_destruct_QToolBarChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QToolBarChangeEvent")
    reinterpret_cast<QToolBarChangeEvent_shell*>(ptr)->~QToolBarChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QToolBarChangeEvent::toggle()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_toggle_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QToolBarChangeEvent::toggle()const", __qt_this)
        __java_return_value = __qt_this->toggle();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QToolBarChangeEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QToolBarChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QToolBarChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QToolBarChangeEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QToolBarChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QToolBarChangeEvent>("QToolBarChangeEvent", "io/qt/widgets/QToolBarChangeEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QToolBarChangeEvent, {
        ConstructorInfo(&__qt_construct_QToolBarChangeEvent_cref_QToolBarChangeEvent, "Lio/qt/widgets/QToolBarChangeEvent;")
       ,ConstructorInfo(&__qt_construct_QToolBarChangeEvent_bool, "Z")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QToolBarChangeEvent);
    registerSizeOfShell(typeId, sizeof(QToolBarChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QToolBarChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
